Class: Google::Apis::ChromewebstoreV2::ItemRevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb

Overview

Details on the status of an item revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemRevisionStatus

Returns a new instance of ItemRevisionStatus.



178
179
180
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distribution_channelsArray<Google::Apis::ChromewebstoreV2::DistributionChannel>

Details on the package of the item Corresponds to the JSON property distributionChannels



171
172
173
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 171

def distribution_channels
  @distribution_channels
end

#stateString

Output only. Current state of the item Corresponds to the JSON property state

Returns:

  • (String)


176
177
178
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 176

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



183
184
185
186
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 183

def update!(**args)
  @distribution_channels = args[:distribution_channels] if args.key?(:distribution_channels)
  @state = args[:state] if args.key?(:state)
end