Class: Google::Apis::ChromewebstoreV2::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb

Overview

Represents a single warning encountered during the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



377
378
379
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the warning. Developers should use this message to understand the warning and take appropriate action to resolve the issue. Corresponds to the JSON property description

Returns:

  • (String)


369
370
371
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 369

def description
  @description
end

#reasonString

The reason for the warning. This is a constant value that identifies the proximate cause of the warning. Corresponds to the JSON property reason

Returns:

  • (String)


375
376
377
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 375

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



382
383
384
385
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 382

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
end