Module: Google::Apis::ChromewebstoreV2
- Defined in:
- lib/google/apis/chromewebstore_v2.rb,
lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/service.rb,
lib/google/apis/chromewebstore_v2/gem_version.rb,
lib/google/apis/chromewebstore_v2/representations.rb
Overview
Chrome Web Store API
The Chrome Web Store API provides access to data about apps and extensions, as well as developer tools for managing them.
Defined Under Namespace
Classes: CancelSubmissionRequest, CancelSubmissionResponse, ChromewebstoreService, DeployInfo, DistributionChannel, FetchItemStatusResponse, ItemRevisionStatus, PublishItemRequest, PublishItemResponse, SetPublishedDeployPercentageRequest, SetPublishedDeployPercentageResponse, UploadItemPackageRequest, UploadItemPackageResponse, Warning, WarningsInfo
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-chromewebstore_v2 gem
"0.3.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260517"- VERSION =
Version of the Chrome Web Store API this client connects to. This is NOT the gem version.
'V2'- AUTH_CHROMEWEBSTORE =
See, edit, update, or publish your Chrome Web Store extensions, themes, apps, and licences you have access to
'https://www.googleapis.com/auth/chromewebstore'- AUTH_CHROMEWEBSTORE_READONLY =
See and download your Chrome Web Store extensions and apps, and see licenses you have access to
'https://www.googleapis.com/auth/chromewebstore.readonly'