Class: Google::Apis::ChromewebstoreV2::DistributionChannel
- Inherits:
-
Object
- Object
- Google::Apis::ChromewebstoreV2::DistributionChannel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb
Overview
Deployment information for a specific release channel
Instance Attribute Summary collapse
-
#crx_version ⇒ String
The extension version provided in the manifest of the uploaded package.
-
#deploy_percentage ⇒ Fixnum
The current deploy percentage for the release channel (nonnegative number between 0 and 100).
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionChannel
constructor
A new instance of DistributionChannel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionChannel
Returns a new instance of DistributionChannel.
87 88 89 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 87 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crx_version ⇒ String
The extension version provided in the manifest of the uploaded package.
Corresponds to the JSON property crxVersion
79 80 81 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 79 def crx_version @crx_version end |
#deploy_percentage ⇒ Fixnum
The current deploy percentage for the release channel (nonnegative number
between 0 and 100).
Corresponds to the JSON property deployPercentage
85 86 87 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 85 def deploy_percentage @deploy_percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
92 93 94 95 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 92 def update!(**args) @crx_version = args[:crx_version] if args.key?(:crx_version) @deploy_percentage = args[:deploy_percentage] if args.key?(:deploy_percentage) end |