Class: Google::Apis::ChromewebstoreV2::FetchItemStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromewebstoreV2::FetchItemStatusResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb
Overview
Response message for FetchItemStatus.
Instance Attribute Summary collapse
-
#item_id ⇒ String
Output only.
-
#last_async_upload_state ⇒ String
Output only.
-
#name ⇒ String
The name of the requested item.
-
#public_key ⇒ String
The public key of the item, which may be generated by the store.
-
#published_item_revision_status ⇒ Google::Apis::ChromewebstoreV2::ItemRevisionStatus
Details on the status of an item revision.
-
#submitted_item_revision_status ⇒ Google::Apis::ChromewebstoreV2::ItemRevisionStatus
Details on the status of an item revision.
-
#taken_down ⇒ Boolean
(also: #taken_down?)
If true, the item has been taken down for a policy violation.
-
#warned ⇒ Boolean
(also: #warned?)
If true, the item has been warned for a policy violation and will be taken down if not resolved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchItemStatusResponse
constructor
A new instance of FetchItemStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchItemStatusResponse
Returns a new instance of FetchItemStatusResponse.
147 148 149 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#item_id ⇒ String
Output only. The ID of the item.
Corresponds to the JSON property itemId
105 106 107 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 105 def item_id @item_id end |
#last_async_upload_state ⇒ String
Output only. The state of the last async upload for an item. Only set when
there has been an async upload for the item in the past 24 hours.
Corresponds to the JSON property lastAsyncUploadState
111 112 113 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 111 def last_async_upload_state @last_async_upload_state end |
#name ⇒ String
The name of the requested item.
Corresponds to the JSON property name
116 117 118 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 116 def name @name end |
#public_key ⇒ String
The public key of the item, which may be generated by the store.
Corresponds to the JSON property publicKey
121 122 123 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 121 def public_key @public_key end |
#published_item_revision_status ⇒ Google::Apis::ChromewebstoreV2::ItemRevisionStatus
Details on the status of an item revision.
Corresponds to the JSON property publishedItemRevisionStatus
126 127 128 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 126 def published_item_revision_status @published_item_revision_status end |
#submitted_item_revision_status ⇒ Google::Apis::ChromewebstoreV2::ItemRevisionStatus
Details on the status of an item revision.
Corresponds to the JSON property submittedItemRevisionStatus
131 132 133 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 131 def submitted_item_revision_status @submitted_item_revision_status end |
#taken_down ⇒ Boolean Also known as: taken_down?
If true, the item has been taken down for a policy violation. Check the
developer dashboard for details.
Corresponds to the JSON property takenDown
137 138 139 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 137 def taken_down @taken_down end |
#warned ⇒ Boolean Also known as: warned?
If true, the item has been warned for a policy violation and will be taken
down if not resolved. Check the developer dashboard for details.
Corresponds to the JSON property warned
144 145 146 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 144 def warned @warned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 152 def update!(**args) @item_id = args[:item_id] if args.key?(:item_id) @last_async_upload_state = args[:last_async_upload_state] if args.key?(:last_async_upload_state) @name = args[:name] if args.key?(:name) @public_key = args[:public_key] if args.key?(:public_key) @published_item_revision_status = args[:published_item_revision_status] if args.key?(:published_item_revision_status) @submitted_item_revision_status = args[:submitted_item_revision_status] if args.key?(:submitted_item_revision_status) @taken_down = args[:taken_down] if args.key?(:taken_down) @warned = args[:warned] if args.key?(:warned) end |