Class: Google::Apis::ChromewebstoreV2::PublishItemRequest
- Inherits:
-
Object
- Object
- Google::Apis::ChromewebstoreV2::PublishItemRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb
Overview
Request message for PublishItem.
Instance Attribute Summary collapse
-
#block_on_warnings ⇒ Boolean
(also: #block_on_warnings?)
Optional.
-
#deploy_infos ⇒ Array<Google::Apis::ChromewebstoreV2::DeployInfo>
Optional.
-
#publish_type ⇒ String
Optional.
-
#skip_review ⇒ Boolean
(also: #skip_review?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublishItemRequest
constructor
A new instance of PublishItemRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublishItemRequest
Returns a new instance of PublishItemRequest.
224 225 226 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_on_warnings ⇒ Boolean Also known as: block_on_warnings?
Optional. When set to true the request will fail if there are any warnings
during validation and the details will be included in the error_details.
Otherwise warnings are treated as non-blocking and will be ignored for
validation but will be included in the response for inspection. Defaults to
false if unset.
Corresponds to the JSON property blockOnWarnings
200 201 202 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 200 def block_on_warnings @block_on_warnings end |
#deploy_infos ⇒ Array<Google::Apis::ChromewebstoreV2::DeployInfo>
Optional. Additional deploy information including the desired initial
percentage rollout. Defaults to the current value saved in the developer
dashboard if unset.
Corresponds to the JSON property deployInfos
208 209 210 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 208 def deploy_infos @deploy_infos end |
#publish_type ⇒ String
Optional. Use this to control if the item is published immediately on approval
or staged for publishing in the future. Defaults to DEFAULT_PUBLISH if unset.
Corresponds to the JSON property publishType
214 215 216 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 214 def publish_type @publish_type end |
#skip_review ⇒ Boolean Also known as: skip_review?
Optional. Whether to attempt to skip item review. The API will validate if the
item qualifies and return a validation error if the item requires review.
Defaults to false if unset.
Corresponds to the JSON property skipReview
221 222 223 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 221 def skip_review @skip_review end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
229 230 231 232 233 234 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 229 def update!(**args) @block_on_warnings = args[:block_on_warnings] if args.key?(:block_on_warnings) @deploy_infos = args[:deploy_infos] if args.key?(:deploy_infos) @publish_type = args[:publish_type] if args.key?(:publish_type) @skip_review = args[:skip_review] if args.key?(:skip_review) end |