Class: Google::Apis::ChromewebstoreV2::UploadItemPackageResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromewebstoreV2::UploadItemPackageResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb
Overview
Response message for UploadItemPackage.
Instance Attribute Summary collapse
-
#crx_version ⇒ String
The extension version provided in the manifest of the uploaded package.
-
#item_id ⇒ String
Output only.
-
#name ⇒ String
The name of the item the package was uploaded to.
-
#upload_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadItemPackageResponse
constructor
A new instance of UploadItemPackageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadItemPackageResponse
Returns a new instance of UploadItemPackageResponse.
348 349 350 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crx_version ⇒ String
The extension version provided in the manifest of the uploaded package. This
will not be set if the upload is still in progress (upload_state is
UPLOAD_IN_PROGRESS).
Corresponds to the JSON property crxVersion
330 331 332 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 330 def crx_version @crx_version end |
#item_id ⇒ String
Output only. The ID of the item the package was uploaded to.
Corresponds to the JSON property itemId
335 336 337 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 335 def item_id @item_id end |
#name ⇒ String
The name of the item the package was uploaded to.
Corresponds to the JSON property name
340 341 342 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 340 def name @name end |
#upload_state ⇒ String
Output only. The state of the upload. If upload_state is UPLOAD_IN_PROGRESS
, you can poll for updates using the fetchStatus method.
Corresponds to the JSON property uploadState
346 347 348 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 346 def upload_state @upload_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
353 354 355 356 357 358 |
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 353 def update!(**args) @crx_version = args[:crx_version] if args.key?(:crx_version) @item_id = args[:item_id] if args.key?(:item_id) @name = args[:name] if args.key?(:name) @upload_state = args[:upload_state] if args.key?(:upload_state) end |