Class: Google::Apis::ChromewebstoreV2::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromewebstore_v2/classes.rb,
lib/google/apis/chromewebstore_v2/representations.rb,
lib/google/apis/chromewebstore_v2/representations.rb

Overview

Represents a single warning encountered during the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



378
379
380
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the warning. Developers should use this message to understand the warning and take appropriate action to resolve the issue. Corresponds to the JSON property description

Returns:

  • (String)


369
370
371
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 369

def description
  @description
end

#reasonString

The reason for the warning. This is a constant value that identifies the proximate cause of the warning. This should be at most 63 characters and match a regular expression of A-Z+[A-Z0-9], which represents UPPER_SNAKE_CASE. Corresponds to the JSON property reason

Returns:

  • (String)


376
377
378
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 376

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



383
384
385
386
# File 'lib/google/apis/chromewebstore_v2/classes.rb', line 383

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
end